import requests
from .login import login
from .user import get_username
from .post import post_text


def _retry(max_retry=100):
    def fn(func):
        def wrapper(self, *args, **kwargs):
            try:
                return func(self, *args, **kwargs)
            except:
                self.login()
                return func(self, *args, **kwargs)

        return wrapper

    return fn


class Weibo:
    def __init__(self, username, password):
        self.username = username
        self.password = password
        self.session = requests.session()
        self.uuid = 0

    def login(self):
        self.uuid, self.session = login(self.username, self.password)
        self.session.headers.update({
            'Referer': 'https://weibo.com/u/%s/home?topnav=1&wvr=6' % self.uuid,
            'Origin': 'https://weibo.com'
        })

    @_retry()
    def get_username(self):
        return get_username(self.session, self.uuid)

    @_retry()
    def post_text(self, text):
        return post_text(self.session, text)

    def post_with_img(self):
        pass

    def repost(self):
        pass

    def comment(self):
        pass



import pytest
import tests
from weibo_web import Weibo

wb = Weibo(tests.username, tests.password)


def test_get_username():
    assert wb.get_username() == '瞎眼看海贼'


def test_post_text():
    res = wb.post_text('发布的微博lai[悲伤]')

    assert res['msg'] == ''



import time


def post_text(session, text):
    unix = int(time.time() * 1e3)
    url = "https://weibo.com/aj/mblog/add?ajwvr=6&__rnd=%s" % unix

    payload = {
        'location': 'v6_content_home',
        'text': text,
        'appkey': '',
        'style_type': 1,
        'pic_id': '',
        'tid': '',
        'pdetail': '',
        'mid': '',
        'isReEdit': False,
        'gif_ids': '',
        'rank': 0,
        'rankid': '',
        'module': 'stissue',
        'pub_source': 'main_',
        'pub_type': 'dialog',
        'isPri': 0,
        '_t': 0
    }

    r = session.post(url, data=payload)
    r.raise_for_status()
    return r.json()
